doapfiend.lexers.SparqlLexer

Package doapfiend :: Module lexers :: Class SparqlLexer |
[hide private]
[frames] | no frames]

# Class SparqlLexer

source code

               object --+
                        |
     pygments.lexer.Lexer --+
                            |
    pygments.lexer.RegexLexer --+
                                |
                               SparqlLexer

Lexer for SPARQL Not Complete

Nested Classes | [hide private]
Inherited from `pygments.lexer.RegexLexer`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `pygments.lexer.RegexLexer`: `get_tokens_unprocessed` Inherited from `pygments.lexer.Lexer`: `__init__`, `__repr__`, `add_filter`, `get_tokens` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Static Methods | [hide private]
Inherited from `pygments.lexer.Lexer`: `analyse_text`

Class Variables | [hide private]
| name = ``'``SPARQL``'`` Name of the lexer
| aliases = ``[``'``sparql``'``]`` Shortcuts for the lexer
| filenames = ``[``'``*.sparql``'``]`` fn match rules
| mimetypes = ``[``'``text/x-sql``'``]`` mime types
| flags = `2` Flags for compiling the regular expressions.
| tokens = ``{``'``comments``'``:` `[``(``'``(\\s*#.*)``'``,` Token.Comment`)``]``,` `'``filterE``...`` Dict of ``{'state': [(regex, tokentype, new_state), ...], ...
Inherited from `pygments.lexer.Lexer`: `alias_filenames`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### tokens Dict of ``{'state': [(regex, tokentype, new_state), ...], ...}`` The initial state is 'root'. ``new_state`` can be omitted to signify no state transition. If it is a string, the state is pushed on the stack and changed. If it is a tuple of strings, all states are pushed on the stack and the current state will be the topmost. It can also be ``combined('state1', 'state2', ...)`` to signify a new, anonymous state combined from the rules of two or more existing ones. Furthermore, it can be '#pop' to signify going back one step in the state stack, or '#push' to push the current state on the stack again. The tuple can also be replaced with ``include('state')``, in which case the rules from the state named by the string are included in the current one. Value:
      {'comments': [('(\\s*#.*)', Token.Comment)],
       'filterExp': ['variable',
                     'object',
                     ('\\s*[+*/<>=~!%&|-]+\\s*', Token.Operator),
                     ('\\s*\\)', Token.Text, '#pop')],
       'graph': [('\\s*(<[^>]*\\>)',
                  Token.Name.Class,
                  ('triple', 'predObj')),
      ...